Canonical reference execution tree. Generic reference interpreter entry points.
The stable statement-IR reference_eval entry point remains delegated to
the existing invocation simulator until Program stores graph nodes
directly.
Modules
- expr
- Expression evaluator that gives the parity engine a pure-Rust ground truth
for every
Exprvariant. - node
- Statement executor that gives the parity engine a pure-Rust ground truth
for every
Nodevariant. - sequential
- Sequential CPU execution model for workgroup parity.
Functions
- reference_
eval - Execute a vyre IR program on the pure Rust reference interpreter.
- run_
arena_ reference - Execute using the statement-IR reference evaluator.
- run_
storage_ graph - Interpret a compact
NodeStoragegraph and return output node values.