Invocation

Struct Invocation 

pub struct Invocation<'a> {
    pub ids: InvocationIds,
    pub returned: bool,
    pub waiting_at_barrier: bool,
    pub uniform_checks: Vec<(usize, bool)>,
    /* private fields */
}
One paused or running invocation.

Fields

ids: InvocationIds

Builtin ids for this invocation.

returned: bool

True after return.

waiting_at_barrier: bool

True when paused at a barrier.

uniform_checks: Vec<(usize, bool)>

Uniform-if observations for branches that contain a barrier.

Implementations

Source

impl<'a> Invocation<'a>

pub fn new(ids: InvocationIds, entry: &'a [Node]) -> Self

Create an invocation at the start of the entry point.

pub fn done(&self) -> bool

Return true when no further execution can occur.

pub fn push_scope(&mut self)

Push a lexical scope.

use vyre_reference::workgroup::{Invocation, InvocationIds};
let mut invocation = Invocation::new(InvocationIds::ZERO, &[]);
invocation.push_scope();
pub fn pop_scope(&mut self)

Pop a lexical scope and remove bindings declared in it.

use vyre_reference::workgroup::{Invocation, InvocationIds};
let mut invocation = Invocation::new(InvocationIds::ZERO, &[]);
invocation.pop_scope();
pub fn local(&self, name: &str) -> Option<&Value>

Look up an active local by name.

pub fn bind(&mut self, name: &str, value: Value) -> Result<(), Error>

Bind a mutable local.

use vyre_reference::{value::Value, workgroup::{Invocation, InvocationIds}};
fn main() -> Result<(), vyre_foundation::Error> {
    let mut invocation = Invocation::new(InvocationIds::ZERO, &[]);
    invocation.bind("example", Value::U32(1))?;
    Ok(())
}
pub fn bind_loop_var(&mut self, name: &str, value: Value) -> Result<(), Error>

Bind an immutable loop variable.

use vyre_reference::{value::Value, workgroup::{Invocation, InvocationIds}};
fn main() -> Result<(), vyre_foundation::Error> {
    let mut invocation = Invocation::new(InvocationIds::ZERO, &[]);
    invocation.bind_loop_var("example", Value::U32(1))?;
    Ok(())
}
pub fn assign(&mut self, name: &str, value: Value) -> Result<(), Error>

Assign an existing mutable local.