LocalSlots

Struct LocalSlots 

pub struct LocalSlots { /* private fields */ }
Shared slot layout for all locals in one program.

Implementations

Source

impl LocalSlots

pub fn for_program(program: &Program) -> Self

Build a slot layout from every binding site in a program.

pub fn for_nodes(nodes: &[Node]) -> Self

Build a slot layout from a node slice.