Module execution

Module execution 

Canonical reference execution tree. Generic reference interpreter entry points.

The stable statement-IR reference_eval entry point remains delegated to the existing invocation simulator until Program stores graph nodes directly.

Modules

expr
Expression evaluator that gives the parity engine a pure-Rust ground truth for every Expr variant.
node
Statement executor that gives the parity engine a pure-Rust ground truth for every Node variant.
sequential
Sequential CPU execution model for workgroup parity.

Functions

reference_eval
Execute a vyre IR program on the pure Rust reference interpreter.
run_arena_reference
Execute using the statement-IR reference evaluator.
run_storage_graph
Interpret a compact NodeStorage graph and return output node values.